@@ -8,7 +8,7 @@ function (x,t,sampling,yule = FALSE,maxitk=5,init=c(-1),posdiv=FALSE,survival=1)
     	rho<-c(sampling,p[3:length(p)])
     	l<-(1:length(rho))*0+ (p[2]/(1-p[1]))
     	mu<-(1:length(rho))*0+  (p[1] * p[2]/(1-p[1]))
-      	out<- treemrcashifts(x,t,l,mu,rho,posdiv,survival)
+      	out<- LikShifts(x,t,l,mu,rho,posdiv,survival)
         out
     }
     numb<-length(t)
